[GSoC][RFC WIP PATCH 3/3] grep: re-enable threads in non-worktree case
- From
Matheus Tavares <matheus.bernardino@usp.br>
- Date
- Jul 19, 2019, 23:08 UTC
- Message-ID
- <e72330c6747218545cce1b6b1edfd1e448141a8f.1563570204.git.matheus.bernardino@usp.br>
- In-Reply-To
- <cover.1563570204.git.matheus.bernardino@usp.br>
They were disabled at 53b8d93 ("grep: disable threading in non-worktree case", 12-12-2011), due to observable perfomance drops. But now that zlib inflation can be performed in parallel, we can regain the speedup.
Grep'ing 'abcd[02]' ("Regex 1") and '(static|extern) (int|double) \*' ("Regex 2") at chromium's repository[1] I got:
Threads | Regex 1 | Regex 2
---------|------------|-----------
1 | 17.5815s | 21.7217s
2 | 9.7983s | 11.3965s
8 | 6.3097s | 6.9667sThese are all means of 30 executions after 2 warmup runs. All tests were executed on a i7-7700HQ with 16GB of RAM and SSD.
[1]: chromium’s repo at commit 03ae96f (“Add filters testing at DSF=2”,
04-06-2019), after a 'git gc' execution.Signed-off-by: Matheus Tavares <matheus.bernardino@usp.br> --- builtin/grep.c | 2 +- 1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/builtin/grep.c b/builtin/grep.c index 682e2461d0..9309dea833 100644 --- a/builtin/grep.c +++ b/builtin/grep.c @@ -1046,7 +1046,7 @@ int cmd_grep(int argc, const char **argv, const char *prefix) pathspec.recursive = 1; pathspec.recurse_submodules = !!recurse_submodules; - if (list.nr || cached || show_in_pager) { + if (show_in_pager) { if (num_threads > 1) warning(_("invalid option combination, ignoring --threads")); num_threads = 1;
-- 2.22.0